|
||||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | |||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | |||||||||
public interface FormatAttribute
Interface for a format attribute validator
| Method Summary | |
|---|---|
EnumSet<NodeType> |
supportedTypes()
Return the set of JSON Schema types this format attribute applies to |
void |
validate(ProcessingReport report,
FullData data)
Validate the instance against this format attribute |
| Method Detail |
|---|
EnumSet<NodeType> supportedTypes()
It is important that this method be implemented correctly. Remind that validation for a given format attribute and an instance which type is not supported always succeeds.
void validate(ProcessingReport report,
FullData data)
throws ProcessingException
report - the report to usedata - the validation data
ProcessingException - an exception occurs (normally, never for a
format attribute)
|
||||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | |||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | |||||||||