|
||||||||||
| PREV NEXT | FRAMES NO FRAMES | |||||||||
| Packages that use Library | |
|---|---|
| com.github.fge.jsonschema.cfg | Validation processor configuration classes |
| com.github.fge.jsonschema.library | Schema keyword libraries |
| com.github.fge.jsonschema.processors.build | Keyword builder processor |
| com.github.fge.jsonschema.processors.digest | Schema digester |
| com.github.fge.jsonschema.processors.format | Format attribute handler |
| com.github.fge.jsonschema.processors.validation | Main validation processors and utility classes |
| Uses of Library in com.github.fge.jsonschema.cfg |
|---|
| Methods in com.github.fge.jsonschema.cfg that return Library | |
|---|---|
Library |
ValidationConfiguration.getDefaultLibrary()
Return the default library to use |
| Methods in com.github.fge.jsonschema.cfg that return types with arguments of type Library | |
|---|---|
Map<JsonRef,Library> |
ValidationConfiguration.getLibraries()
Return the map of libraries for this configuration |
| Methods in com.github.fge.jsonschema.cfg with parameters of type Library | |
|---|---|
ValidationConfigurationBuilder |
ValidationConfigurationBuilder.addLibrary(String uri,
Library library)
Add a $schema and matching library to this configuration |
ValidationConfigurationBuilder |
ValidationConfigurationBuilder.setDefaultLibrary(String uri,
Library library)
Add a library and sets it as the default |
| Uses of Library in com.github.fge.jsonschema.library |
|---|
| Methods in com.github.fge.jsonschema.library that return Library | |
|---|---|
Library |
LibraryBuilder.freeze()
Return a frozen version of this builder |
static Library |
DraftV4Library.get()
|
static Library |
DraftV3Library.get()
|
| Uses of Library in com.github.fge.jsonschema.processors.build |
|---|
| Constructors in com.github.fge.jsonschema.processors.build with parameters of type Library | |
|---|---|
ValidatorBuilder(Library library)
|
|
| Uses of Library in com.github.fge.jsonschema.processors.digest |
|---|
| Constructors in com.github.fge.jsonschema.processors.digest with parameters of type Library | |
|---|---|
SchemaDigester(Library library)
|
|
| Uses of Library in com.github.fge.jsonschema.processors.format |
|---|
| Constructors in com.github.fge.jsonschema.processors.format with parameters of type Library | |
|---|---|
FormatProcessor(Library library)
|
|
| Uses of Library in com.github.fge.jsonschema.processors.validation |
|---|
| Constructors in com.github.fge.jsonschema.processors.validation with parameters of type Library | |
|---|---|
ValidationChain(RefResolver refResolver,
Library library,
boolean useFormat)
|
|
|
||||||||||
| PREV NEXT | FRAMES NO FRAMES | |||||||||