|
||||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | |||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | |||||||||
java.lang.Objectcom.github.fge.jsonschema.processors.data.FullData
@Immutable public final class FullData
Validation data for a validation processor
The included data are the schema (in the shape of a SchemaTree and
the instance to validate (in the shape of a JsonTree.
The ProcessingMessage template generated contains information
about both the schema and instance.
| Constructor Summary | |
|---|---|
FullData(SchemaTree schema)
|
|
FullData(SchemaTree schema,
JsonTree instance)
|
|
| Method Summary | |
|---|---|
JsonTree |
getInstance()
|
SchemaTree |
getSchema()
|
ProcessingMessage |
newMessage()
|
FullData |
withInstance(JsonTree instance)
Return a new full data with another instance |
FullData |
withSchema(SchemaTree schema)
Return a new full data with another schema |
| Methods inherited from class java.lang.Object |
|---|
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait |
| Constructor Detail |
|---|
public FullData(SchemaTree schema,
JsonTree instance)
public FullData(SchemaTree schema)
| Method Detail |
|---|
public SchemaTree getSchema()
public JsonTree getInstance()
public FullData withSchema(SchemaTree schema)
schema - the schema
public FullData withInstance(JsonTree instance)
instance - the new instance
public ProcessingMessage newMessage()
newMessage in interface MessageProvider
|
||||||||||
| PREV CLASS NEXT CLASS | FRAMES NO FRAMES | |||||||||
| SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD | |||||||||