|
||||||||||
| PREV NEXT | FRAMES NO FRAMES | |||||||||
| Packages that use FormatAttribute | |
|---|---|
| com.github.fge.jsonschema.format | Format attribute base classes |
| com.github.fge.jsonschema.format.common | Common format attribute classes for draft v3 and draft v4 |
| com.github.fge.jsonschema.format.draftv3 | Format attributes specific to draft v3 |
| com.github.fge.jsonschema.format.helpers | Helper classes for format attributes |
| com.github.fge.jsonschema.library | Schema keyword libraries |
| com.github.fge.jsonschema.library.format | Dictionaries of builtin FormatAttributes |
| com.github.fge.jsonschema.processors.format | Format attribute handler |
| Uses of FormatAttribute in com.github.fge.jsonschema.format |
|---|
| Classes in com.github.fge.jsonschema.format that implement FormatAttribute | |
|---|---|
class |
AbstractFormatAttribute
Base abstract class for a format attribute |
| Uses of FormatAttribute in com.github.fge.jsonschema.format.common |
|---|
| Classes in com.github.fge.jsonschema.format.common that implement FormatAttribute | |
|---|---|
class |
DateTimeAttribute
Validator for the date-time format attribute |
class |
EmailAttribute
Validator for the email format attribute. |
class |
IPv6Attribute
Validator for the ipv6 format attribute. |
class |
RegexAttribute
Validator for the regex format attribute. |
class |
URIAttribute
Validator for the uri format attribute. |
| Methods in com.github.fge.jsonschema.format.common that return FormatAttribute | |
|---|---|
static FormatAttribute |
URIAttribute.getInstance()
|
static FormatAttribute |
RegexAttribute.getInstance()
|
static FormatAttribute |
IPv6Attribute.getInstance()
|
static FormatAttribute |
EmailAttribute.getInstance()
|
static FormatAttribute |
DateTimeAttribute.getInstance()
|
| Uses of FormatAttribute in com.github.fge.jsonschema.format.draftv3 |
|---|
| Classes in com.github.fge.jsonschema.format.draftv3 that implement FormatAttribute | |
|---|---|
class |
DateAttribute
Validator for the date format attribute. |
class |
PhoneAttribute
Attempt to validate the phone format attribute. |
class |
TimeAttribute
Validator for the time format attribute. |
class |
UTCMillisecAttribute
Validator for the utc-millisec format attribute. |
| Methods in com.github.fge.jsonschema.format.draftv3 that return FormatAttribute | |
|---|---|
static FormatAttribute |
UTCMillisecAttribute.getInstance()
|
static FormatAttribute |
TimeAttribute.getInstance()
|
static FormatAttribute |
PhoneAttribute.getInstance()
|
static FormatAttribute |
DateAttribute.getInstance()
|
| Uses of FormatAttribute in com.github.fge.jsonschema.format.helpers |
|---|
| Classes in com.github.fge.jsonschema.format.helpers that implement FormatAttribute | |
|---|---|
class |
DateFormatAttribute
Abstract class for date/time related format attributes |
class |
IPv4FormatAttribute
Validator for both the ip-address (draft v3) and ipv4 (draft
v4) format attributes. |
class |
SharedHostNameAttribute
Validator for the host-name format attribute. |
| Uses of FormatAttribute in com.github.fge.jsonschema.library |
|---|
| Methods in com.github.fge.jsonschema.library that return types with arguments of type FormatAttribute | |
|---|---|
Dictionary<FormatAttribute> |
Library.getFormatAttributes()
Get the dictionary of format attributes |
| Methods in com.github.fge.jsonschema.library with parameters of type FormatAttribute | |
|---|---|
LibraryBuilder |
LibraryBuilder.addFormatAttribute(String name,
FormatAttribute attribute)
Add a format attribute |
| Uses of FormatAttribute in com.github.fge.jsonschema.library.format |
|---|
| Methods in com.github.fge.jsonschema.library.format that return types with arguments of type FormatAttribute | |
|---|---|
static Dictionary<FormatAttribute> |
DraftV4FormatAttributesDictionary.get()
|
static Dictionary<FormatAttribute> |
DraftV3FormatAttributesDictionary.get()
|
static Dictionary<FormatAttribute> |
CommonFormatAttributesDictionary.get()
|
| Uses of FormatAttribute in com.github.fge.jsonschema.processors.format |
|---|
| Constructor parameters in com.github.fge.jsonschema.processors.format with type arguments of type FormatAttribute | |
|---|---|
FormatProcessor(Dictionary<FormatAttribute> dict)
|
|
|
||||||||||
| PREV NEXT | FRAMES NO FRAMES | |||||||||